@@ -2,6 +2,10 @@
 
 from __future__ import (absolute_import, division, print_function,
                         unicode_literals)
+import pkg_resources
+# Module version, as defined in PEP-0396.
+__version__ = pkg_resources.get_distribution('bag').version
+del pkg_resources
 
 _boolean_states = {'1': True, 'yes': True, 'true': True, 'on': True,
                    '0': False, 'no': False, 'false': False, 'off': False}
