@@ -1,8 +1,9 @@
 # -*- coding: utf-8 -*-
 from __future__ import (absolute_import, division, print_function,
-    unicode_literals)
+                        unicode_literals)
 import os
 import stat
+from nine import str
 from pyramid.config import Configurator
 from pyramid.resource import abspath_from_resource_spec
 from pyramid.response import FileResponse
@@ -35,7 +36,7 @@ view_classes = []
 def subdict(adict, prefix):
     '''Returns a new dict based on keys that start with a prefix.'''
     lprefix = len(prefix)
-    return {key[lprefix:]: val for key, val in adict.items() \
+    return {key[lprefix:]: val for key, val in adict.items()
             if key.startswith(prefix)}
 
 
@@ -146,7 +147,7 @@ class PyramidStarter(object):
             class Sender(object):                 # Provide Ptah with an object
                 def send(self, author, to, msg):  # that has a send() method.
                     from quopri import decodestring
-                    m = mailer.new(to=to, subject=unicode(msg['subject']),
+                    m = mailer.new(to=to, subject=str(msg['subject']),
                         plain=decodestring(msg.get_payload()))
                     mailer.send(m)
             self.config.ptah_init_mailer(Sender())
